@@ -1,7 +1,8 @@
 # -*- coding: utf-8 -*-
+from mootdx import config
 from mootdx.consts import EX_HOSTS, GP_HOSTS, HQ_HOSTS
 
-__version__ = "0.6.11"
+__version__ = '0.7.0'
 __author__ = "bopo.wang<ibopo@126.com>"
 
 CONFIG = {
@@ -21,3 +22,6 @@ CONFIG = {
 
 def bestip():
     return
+
+
+config.setup()
