@@ -1,7 +1,5 @@
 # -*- coding: utf-8 -*-
-
-from pytdx.reader import (BlockReader, CustomerBlockReader,
-                          TdxExHqDailyBarReader, TdxLCMinBarReader)
+from pytdx.reader import (BlockReader, CustomerBlockReader, TdxExHqDailyBarReader, TdxLCMinBarReader)
 from unipath import Path
 
 from mootdx.consts import TYPE_GROUP
@@ -44,27 +42,30 @@ class ReaderBase(object):
             self.tdxdir = tdxdir
         else:
             log.error('tdxdir 目录不存在')
+            raise Exception('tdxdir 目录不存在')
 
-    def find_path(self, symbol=None, subdir='lday', ext=None):
+    def find_path(self, symbol=None, subdir='lday', suffix=None):
         """
         自动匹配文件路径，辅助函数
 
         :param symbol:
         :param subdir:
-        :param ext:
+        :param suffix:
         :return: pd.dataFrame or None
         """
         market = get_stock_market(symbol, True) if len(symbol.split('#')) == 1 else 'ds'
         prefix = market if len(symbol.split('#')) == 1 else ''
-        ext = ext if isinstance(ext, list) else [ext]
+        suffix = suffix if isinstance(suffix, list) else [suffix]
 
-        for ex_ in ext:
-            vipdoc = Path(self.tdxdir, market, subdir, prefix, symbol, ex_)
+        for ex_ in suffix:
+            ex_ = ex_.strip('.')
+            vipdoc = Path(self.tdxdir, 'vipdoc', market, subdir, f'{prefix}{symbol}.{ex_}')
 
-            if not Path(vipdoc).exists():
+            if Path(vipdoc).exists():
+                log.debug(f"所需的文件: {vipdoc}")
                 return vipdoc
             else:
-                log.debug('未找到所需的文件: {}'.format(vipdoc))
+                log.debug(f'未找到所需的文件: {vipdoc}')
 
         return None
 
@@ -80,7 +81,7 @@ class StdReader(ReaderBase):
         :return: pd.dataFrame or None
         """
         reader = MooTdxDailyBarReader()
-        vipdoc = self.find_path(symbol=symbol, subdir='lday', ext='day')
+        vipdoc = self.find_path(symbol=symbol, subdir='lday', suffix='day')
 
         if vipdoc is not None:
             return reader.get_df(vipdoc)
@@ -97,7 +98,7 @@ class StdReader(ReaderBase):
         """
         subdir = 'fzline' if str(suffix) == '5' else 'minline'
         suffix = ['lc5', '5'] if str(suffix) == '5' else ['lc1', '1']
-        symbol = self.find_path(symbol, subdir=subdir, ext=suffix)
+        symbol = self.find_path(symbol, subdir=subdir, suffix=suffix)
         reader = TdxLCMinBarReader()
 
         if symbol is not None:
@@ -140,12 +141,40 @@ class ExtReader(ReaderBase):
 
     def daily(self, symbol=None):
         """
-        获取日线数据
+        获取扩展市场日线数据
 
         :return: pd.dataFrame or None
         """
         reader = TdxExHqDailyBarReader()
-        vipdoc = self.find_path(symbol=symbol, subdir='lday', ext='day')
+        vipdoc = self.find_path(symbol=symbol, subdir='lday', suffix='day')
+
+        if symbol is not None:
+            return reader.get_df(vipdoc)
+
+        return None
+
+    def minute(self, symbol=None):
+        """
+        获取扩展市场分钟线数据
+
+        :return: pd.dataFrame or None
+        """
+        reader = TdxExHqDailyBarReader()
+        vipdoc = self.find_path(symbol=symbol, subdir='minline', suffix='lc1')
+
+        if symbol is not None:
+            return reader.get_df(vipdoc)
+
+        return None
+
+    def fzline(self, symbol=None):
+        """
+        获取日线数据
+
+        :return: pd.dataFrame or None
+        """
+        reader = TdxExHqDailyBarReader()
+        vipdoc = self.find_path(symbol=symbol, subdir='fzline', suffix='lc5')
 
         if symbol is not None:
             return reader.get_df(vipdoc)
