@@ -43,7 +43,7 @@ def get_stock_market(symbol='', string=False):
     if symbol.startswith(('sh', 'sz')):
         market = symbol[:2]
 
-    elif symbol.startswith(('50', '51', '60', '90', '110', '113', '132', '204')):
+    elif symbol.startswith(('50', '51', '60', '68', '90', '110', '113', '132', '204')):
         market = 'sh'
 
     elif symbol.startswith(('00', '12', '13', '18', '15', '16', '18', '20', '30', '39', '115', '1318')):
@@ -65,7 +65,7 @@ def parse_gpcw(filename):
 
 def gpcw(filepath):
     cw_file = open(filepath, 'rb')
-    
+
     header_size = calcsize("<3h1H3L")
     stock_item_size = calcsize("<6s1c1L")
 
@@ -95,7 +95,7 @@ def md5sum(downfile):
     :param downfile:
     :return:
     """
-    
+
     try:
         md5_l = hashlib.md5()
         md5_l.update(Path(downfile).read_file('rb'))
@@ -113,6 +113,8 @@ def to_data(v):
     :return: pd.DataFrame
     """
 
+    log.debug(v)
+
     if not v:
         return pd.DataFrame(data=[])
 
